@@ -6,10 +6,11 @@ Copyright 2021--2022 Michael Hayes, UCECE
 
 from .expr import expr, equation, ExprTuple
 from .nexpr import DiscreteTimeDomainExpression
-from .diffeq import DifferenceEquation
+from .differenceequation import DifferenceEquation
 from .discretetime import n, z, seq
 from .sequence import Sequence
 from .utils import isiterable
+from .sym import oo
 import sympy as sym
 
 
@@ -80,6 +81,11 @@ class DLTIFilter(object):
 
         return G(n)
 
+    def frequency_response(self, var=None, images=oo, **assumptions):
+        """Return frequency response."""
+
+        return self.transfer_function().DTFT(var, images, **assumptions)
+
     def difference_equation(self, inputsym='x', outputsym='y'):
         """Return difference equation."""
 
@@ -95,11 +101,16 @@ class DLTIFilter(object):
         return DifferenceEquation(lhs, rhs, inputsym, outputsym)
 
     def zdomain_initial_response(self, ic):
-        """Return Z-domain response due to initial conditions.
+        """Return z-domain response due to initial conditions.
            ic : list with initial values y[-1], y[-2], ...
         """
 
+        from .sym import zsym
+
         Nl = len(self.a)
+        if len(ic) != Nl:
+            raise ValueError('Expecting %d initial conditions, got %d'
+                             % (Nl, len(ic)))
 
         # Denominator for Yi(z)
         denom = self.a[0] * z**0
@@ -114,8 +125,11 @@ class DLTIFilter(object):
             num += az * y0
 
         # Collect with respect to positive powers of the variable z
-        num = sym.collect(sym.expand(num * z**Nl), z)
-        denom = sym.collect(sym.expand(denom * z**Nl), z)
+        num = num.sympy * zsym**Nl
+        denom = denom.sympy * zsym**Nl
+
+        num = sym.collect(sym.expand(num), zsym)
+        denom = sym.collect(sym.expand(denom), zsym)
 
         Yzi = expr(-sym.simplify(num / denom))
         Yzi.is_causal = True
@@ -219,3 +233,10 @@ class DLTIFilter(object):
         import pdb
         pdb.set_trace()
         return self
+
+    @property
+    def is_stable(self):
+        """Return True if all the poles of the filters transfer function
+        are within the unit circle."""
+
+        return self.transfer_function().is_stable
