@@ -18,6 +18,7 @@ from sympy import Sum
 
 __all__ = ('kexpr', )
 
+
 class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression):
     """Discrete Fourier domain expression or symbol."""
 
@@ -30,7 +31,8 @@ class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression)
         if 'integer' not in assumptions:
             assumptions['real'] = True
 
-        super(DiscreteFourierDomainExpression, self).__init__(val, **assumptions)
+        super(DiscreteFourierDomainExpression,
+              self).__init__(val, **assumptions)
 
         expr = self.expr
         if check and expr.has(zsym):
@@ -86,12 +88,12 @@ class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression)
         the extent of the inverse DFT.  By default `N` is defined as
         'N'."""
 
-        from .sym import symsymbol
+        from .sym import miscsymbol
 
         if N is None:
-            N = symsymbol('N', integer=True, positive=True)
+            N = miscsymbol('N', integer=True, positive=True)
         elif isinstance(N, str):
-            N = symsymbol(N, integer=True, positive=True)
+            N = miscsymbol(N, integer=True, positive=True)
 
         result = IDFT(self.expr, ksym, nsym, N, evaluate=evaluate)
         result = self.change(result, domain='discrete time')
@@ -147,7 +149,7 @@ def kexpr(arg, **assumptions):
     return DiscreteFourierDomainExpression(arg, **assumptions)
 
 
-from .expressionclasses import expressionclasses
+from .expressionclasses import expressionclasses  # nopep8
 
 expressionclasses.register('discrete fourier', DiscreteFourierDomainExpression)
 
