@@ -2,22 +2,25 @@
 This module performs loop analysis.  It is primarily for showing
 the equations rather than evaluating them.
 
-Copyright 2019--2021 Michael Hayes, UCECE
+Copyright 2019--2022 Michael Hayes, UCECE
 
 """
 
 # TODO, handle current sources and dependent sources.
 
 from .circuitgraph import CircuitGraph
-from .expr import expr, equation
+from .expr import expr, equation, ExprTuple
 from .systemequations import SystemEquations
 import sympy as sym
 
 
 class LoopAnalysis(object):
-    """
-    This is an experimental class for loop analysis.  The API
-    is likely to change since different invocations find different loops.
+    """This is an experimental class for loop analysis.  Currently,
+    it uses mesh analysis and so is only applicable to circuits with
+    a planar topology.
+
+    The API is likely to change since different invocations find
+    different current loops.
 
     >>> from lcapy import Circuit, LoopAnalysis
     >>> cct = Circuit('''
@@ -30,7 +33,7 @@ class LoopAnalysis(object):
     ... C1 5 6; right=2
     ...''')
 
-    To perform nodal analysis in the time domain:
+    To perform loop analysis in the time domain:
 
     >>> la = LoopAnalysis(cct)
 
@@ -153,7 +156,7 @@ class LoopAnalysis(object):
                             current += mesh_currents[n]
                             break
 
-                v = elt.cpt.v_equation(current, self.kind)
+                v = elt.cpt.voltage_equation(current, self.kind)
                 if elt.is_voltage_source and is_reversed:
                     v = -v
                 result += v
@@ -242,6 +245,21 @@ class LoopAnalysis(object):
             self._sys = self._analyse()
         return self._sys.format(form, invert)
 
+    @property
+    def unknowns(self):
+        """Return tuple of the unknown voltages"""
+
+        return ExprTuple(self.y)
+
+    def solve_laplace(self):
+        """Determine the unknown voltages using Laplace transforms and
+        return as a dict"""
+
+        from .sexpr import s
+
+        unknowns = self.unknowns(s)
+        return self.mesh_equations()(s).solve(unknowns)
+
 
 from .expr import ExprList, ExprDict, expr  # nopep8
 from .current import Iname  # nopep8
