@@ -12,7 +12,7 @@ from .cexpr import ConstantDomainExpression
 from .omegaexpr import AngularFourierDomainExpression
 from .symbols import j, omega, jomega, s, t
 from .functions import sqrt
-from .sym import capitalize_name, omegasym
+from .sym import capitalize_name, omegasym, eps
 from .grammar import delimiters
 from .immittancemixin import ImmittanceMixin
 from .superpositioncurrent import SuperpositionCurrent
@@ -50,6 +50,7 @@ class Cpt(ImmittanceMixin):
     add_parallel = False
     equipotential_nodes = ()
     is_transformer = False
+    is_switch = False
 
     def __init__(self, cct, namespace, defname, name, cpt_type, cpt_id, string,
                  opts_string, nodes, keyword, *args):
@@ -157,13 +158,18 @@ class Cpt(ImmittanceMixin):
         opts = self.opts.copy()
         opts.add(s)
 
-        return self._netmake(opts=opts)
+        return self._netmake_opts(opts)
 
     def _kill(self):
         """Kill sources."""
 
         return self._copy()
 
+    def _replace_switch(self, t, before=False):
+        """Replace switch with short-circuit or open-circuit at time t."""
+
+        return self._copy()
+
     def _subs(self, subs_dict):
         """Substitute values using dictionary of substitutions.
         If a scalar is passed, this is substituted for the component value.
@@ -228,7 +234,8 @@ class Cpt(ImmittanceMixin):
 
         return self._netsubs(node_map)
 
-    def _netmake1(self, name, nodes=None, args=None, opts=None):
+    def _netmake1(self, name, nodes=None, args=None, opts=None,
+                  ignore_keyword=False):
 
         if nodes is None:
             nodes = self.relnodes
@@ -250,32 +257,36 @@ class Cpt(ImmittanceMixin):
             fmtargs = []
 
         parts = [name]
-        parts.extend(nodes)
+        for m, node in enumerate(nodes):
+            parts.append(node)
+            if not ignore_keyword and self.keyword[0] == m + 1:
+                parts.append(self.keyword[1])
         parts.extend(fmtargs)
 
-        # Insert keyword...
-        if self.keyword[0] == 0:
-            parts.append(self.keyword[1])
-
         net = ' '.join(parts)
         opts_str = str(opts).strip()
         if opts_str != '':
             net += '; ' + opts_str
         return net
 
-    def _netmake(self, nodes=None, args=None, opts=None):
+    def _netmake(self, nodes=None, args=None, opts=None, ignore_keyword=False):
         """This keeps the same cpt name"""
-        return self._netmake1(self.namespace + self.relname, nodes, args, opts)
+        return self._netmake1(self.namespace + self.relname, nodes, args, opts,
+                              ignore_keyword=ignore_keyword)
 
     def _netmake_W(self, nodes=None, opts=None):
         """This is used for changing cpt name from L1 to W"""
         return self._netmake1(self.namespace + 'W', nodes, args=(),
-                              opts=opts)
+                              opts=opts, ignore_keyword=True)
 
     def _netmake_O(self, nodes=None, opts=None):
         """This is used for changing cpt name from C1 to O"""
         return self._netmake1(self.namespace + 'O', nodes, args=(),
-                              opts=opts)
+                              opts=opts, ignore_keyword=True)
+
+    def _netmake_opts(self, opts=None):
+        """This is used for changing the opts"""
+        return self._netmake1(self.namespace + self.relname, opts=opts)
 
     def _netmake_variant(self, newtype, nodes=None, args=None, opts=None,
                          suffix=''):
@@ -288,11 +299,10 @@ class Cpt(ImmittanceMixin):
         """This is used for expanding a component into multiple components"""
 
         name = self.namespace + name + '__' + self.relname
-        return self._netmake1(name, nodes, args, opts)
+        return self._netmake1(name, nodes, args, opts, ignore_keyword=True)
 
     def _select(self, kind=None):
-        """Select domain kind for component."""
-        raise ValueError('Component not a source: %s' % self)
+        return self._copy()
 
     def _new_value(self, value, ic=None):
 
@@ -747,7 +757,7 @@ class TimeVarying(Invalid):
 
     def _stamp(self, mna):
         raise NotImplementedError(
-            'Cannot analyse time-varying component: %s' % self)
+            'Cannot analyse time-varying component (use convert_IVP): %s' % self)
 
 
 class Logic(Invalid):
@@ -888,7 +898,10 @@ class RC(RLC):
         n1, n2 = mna._cpt_node_indexes(self)
 
         if self.type == 'C' and mna.kind == 'dc':
-            Y = 0
+            # Assume a conductance of eps in parallel with the
+            # capacitor.  After the matrix inversion, the limit
+            # will be calculated for eps=0.
+            Y = eps
         else:
             Y = self.Y.sympy
 
@@ -917,6 +930,15 @@ class C(RC):
     def C(self):
         return self.cpt.C
 
+    # Replace C with open-circuit for DC but this loses branch current through C
+    # def _select(self, kind=None):
+    #     if kind != 'dc':
+    #         return self._copy()
+    #
+    #     copts = self.opts.copy()
+    #     copts.add('nosim')
+    #     return self._netmake_opts(copts) + '\n' + self._netmake_O()
+
     def _kill(self):
         """Kill implicit sources due to initial conditions."""
         return self.netmake(args=self.args[0])
@@ -1276,7 +1298,8 @@ class I(IndependentSource):
 
     def _select(self, kind=None):
         """Select domain kind for component."""
-        return self._netmake(args=self.cpt.Isc.netval(kind))
+        return self._netmake(args=self.cpt.Isc.netval(kind),
+                             ignore_keyword=True)
 
     def _kill(self):
         newopts = self.opts.copy()
@@ -1573,6 +1596,58 @@ class SPppm(Dummy):
             mna._C[m, n4] += 1
 
 
+class SW(TimeVarying):
+    """Switch"""
+
+    is_switch = True
+
+    def _replace_switch(self, t, before=False):
+        """Replace switch with open-circuit or short-circuit
+        using specified time `t`."""
+
+        kind = self.__class__.__name__
+
+        active_time = expr(self.args[0])
+
+        if before:
+            active = expr(t) < active_time
+        else:
+            active = expr(t) >= active_time
+
+        if kind in ('SW', 'SWno', 'SWpush'):
+            if active:
+                return self._netmake_W()
+            return self._netmake_O()
+        elif kind in ('SWnc', ):
+            if active:
+                return self._netmake_O()
+            return self._netmake_W()
+        elif kind in ('SWspdt', ):
+
+            opts = self.opts.copy()
+            opts.add('nosim')
+            if 'l' not in opts:
+                # Remove label
+                opts.add('l=')
+
+            wopts = self.opts.copy()
+            wopts.add('ignore')
+
+            if active:
+                if 'mirror' in opts:
+                    opts.remove('mirror')
+                else:
+                    opts.add('mirror')
+            net = self._netmake_opts(opts)
+
+            if active ^ ('mirror' in self.opts):
+                return net + '\n' + self._netmake_W(nodes=(self.relnodes[0], self.relnodes[2]), opts=wopts)
+            return net + '\n' + self._netmake_W(nodes=(self.relnodes[0], self.relnodes[1]), opts=wopts)
+
+        else:
+            raise RuntimeError('Internal error, unhandled switch %s' % self)
+
+
 class TF(Cpt):
     """Transformer"""
 
@@ -1867,7 +1942,8 @@ class V(IndependentSource):
 
     def _select(self, kind=None):
         """Select domain kind for component."""
-        return self._netmake(args=self.cpt.Voc.netval(kind))
+        return self._netmake(args=self.cpt.Voc.netval(kind),
+                             ignore_keyword=True)
 
     def _kill(self):
         newopts = self.opts.copy()
@@ -1908,12 +1984,12 @@ class W(Dummy):
     def _stamp(self, mna):
         pass
 
-    @property
+    @ property
     def I(self):
         raise ValueError(
             'Cannot determine current through wire, use a 0 V voltage source')
 
-    @property
+    @ property
     def i(self):
         raise ValueError(
             'Cannot determine current through wire, use a 0 V voltage source')
@@ -2014,11 +2090,10 @@ defcpt('Sbox', Misc, 'Box shape')
 defcpt('Scircle', Misc, 'Circle shape')
 defcpt('Sellipse', Misc, 'Ellipse shape')
 defcpt('Striangle', Misc, 'Triangle shape')
-defcpt('SW', TimeVarying, 'Switch')
-defcpt('SWno', 'SW', 'Normally open switch')
-defcpt('SWnc', 'SW', 'Normally closed switch')
-defcpt('SWpush', 'SW', 'Pushbutton switch')
-defcpt('SWspdt', 'SW', 'SPDT switch')
+defcpt('SWno', SW, 'Normally open switch')
+defcpt('SWnc', SW, 'Normally closed switch')
+defcpt('SWpush', SW, 'Pushbutton switch')
+defcpt('SWspdt', SW, 'SPDT switch')
 
 defcpt('TFcore', TF, 'Transformer with core')
 defcpt('TFtapcore', TFtap, 'Transformer with core')
