@@ -6,6 +6,7 @@ Copyright 2020--2022 Michael Hayes, UCECE
 """
 
 from .expr import expr
+from .analysis import Analysis
 from .mnacpts import Cpt
 from .impedance import impedance
 from .admittance import admittance
@@ -1313,10 +1314,7 @@ class NetlistMixin(object):
         new = self._new()
 
         for cpt in self._elements.values():
-            if cpt.independent_source:
-                net = cpt._select(kind)
-            else:
-                net = cpt._copy()
+            net = cpt._select(kind)
             new._add(net)
         return new
 
@@ -1336,6 +1334,71 @@ class NetlistMixin(object):
             cpt = cpt.name
         return self.elements[cpt].short_circuit()
 
+    def convert_IVP(self, t=0):
+        """Remove switches from netlist and convert to an initial value
+        problem. `t` is used to determine the state of the switches."""
+
+        times = self.switching_times()
+        if times == ():
+            warn('Netlist has no switches')
+            return self
+
+        if t < times[0]:
+            return self.replace_switches(t)
+
+        cct = self
+        for m, time in enumerate(times):
+            if time > t:
+                break
+            before = cct.replace_switches_before(time)
+            cct = cct.replace_switches(time).initialize(before, time)
+
+        if time != 0:
+            warn('Note, the time t is relative to %s' % time)
+
+        return cct
+
+    def _replace_switches(self, t=0, switchnames=None, before=False):
+        """Replace specified switches with wire or open circuit
+        for time `t`.   If `switchnames` is not specified, all switches
+        are replaced."""
+
+        new = self._new()
+
+        for cpt in self._elements.values():
+            if switchnames is None or cpt.name in switchnames:
+                net = cpt._replace_switch(t, before=before)
+            else:
+                net = cpt._copy()
+            new._add(net)
+        return new
+
+    def replace_switches(self, t=0, switchnames=None):
+        """Replace specified switches with open-circuit or short-circuit for
+        time at or after `t`.  If `switchnames` is not specified, all
+        switches are replaced."""
+
+        return self._replace_switches(t, switchnames, before=False)
+
+    def replace_switches_before(self, t=0, switchnames=None):
+        """Replace specified switches with open-circuit or short-circuit for
+        time just before `t`.  If `switchnames` is not specified, all
+        switches are replaced."""
+
+        return self._replace_switches(t, switchnames, before=True)
+
+    def switching_times(self, tmax=1e12):
+        """Return sorted list of the times that switches activate prior to
+        `tmax`."""
+
+        times = []
+        for cpt in self._elements.values():
+            if cpt.type.startswith('SW'):
+                active_time = float(cpt.args[0])
+                if active_time < tmax and active_time not in times:
+                    times.append(active_time)
+        return sorted(times)
+
     def _kill(self, sourcenames):
 
         new = self._new()
@@ -2163,20 +2226,20 @@ class NetlistMixin(object):
     def is_causal(self):
         """Return True if all independent sources are causal and not an
         initial value problem (unless all the initial values are zero)."""
-        return self.analysis['causal']
+        return self.analysis.causal
 
     @property
     def is_dc(self):
         """Return True if all independent sources are DC and not an
         initial value problem.  The initial value problem may collapse
         to a DC problem but we cannot prove this yet."""
-        return self.analysis['dc']
+        return self.analysis.dc
 
     @property
     def is_ac(self):
         """Return True if all independent sources are AC and not an
         initial value problem."""
-        return self.analysis['ac']
+        return self.analysis.ac
 
     @property
     def is_superposition(self):
@@ -2190,41 +2253,55 @@ class NetlistMixin(object):
     @property
     def has_dc(self):
         """Return True if any independent source has a DC component."""
-        return self.analysis['has_dc']
+        return self.analysis.has_dc
 
     @property
     def has_ac(self):
         """Return True if any independent source has an AC component."""
-        return self.analysis['has_ac']
+        return self.analysis.has_ac
 
     @property
     def has_s_transient(self):
         """Return True if any independent source has a transient component defined in s-domain."""
-        return self.analysis['has_s']
+        return self.analysis.has_s
 
     @property
     def has_transient(self):
         """Return True if any independent source has a transient component."""
-        return self.analysis['has_transient']
+        return self.analysis.has_transient
 
     @property
     def zeroic(self):
         """Return True if the initial conditions for all components are zero."""
-        return self.analysis['zeroic']
+        return self.analysis.zeroic
 
     @property
-    def is_ivp(self):
+    def is_IVP(self):
         """Return True for an initial value problem.  This is True if any
         component that allows initial conditions has them explicitly
         defined.
 
         """
-        return self.analysis['ivp']
+        return self.analysis.ivp
+
+    @property
+    def is_ivp(self):
+        LcapyDeprecationWarning(
+            feature="is_ivp",
+            useinstead="is_IVP",
+            deprecated_since_version="1.7"
+        ).warn()
+        return self.is_IVP
+
+    @property
+    def is_switching(self):
+        """Return True for a switching circuit."""
+        return self.analysis.switching
 
     @property
     def is_time_domain(self):
         """Return True if can analyse in time domain."""
-        return self.analysis['time_domain']
+        return self.analysis.time_domain
 
     @property
     def missing_ic(self):
@@ -2244,56 +2321,56 @@ class NetlistMixin(object):
     def reactances(self):
         """Return dictionary of reactances."""
 
-        return self.analysis['reactances']
+        return self.analysis.reactances
 
     @property
     def transformers(self):
         """Return dictionary of transformers."""
 
-        return self.analysis['transformers']
+        return self.analysis.transformers
 
     @property
     def capacitors(self):
         """Return dictionary of capacitors."""
 
-        return self.analysis['capacitors']
+        return self.analysis.capacitors
 
     @property
     def inductors(self):
         """Return dictionary of inductors."""
 
-        return self.analysis['inductors']
+        return self.analysis.inductors
 
     @property
     def voltage_sources(self):
         """Return dictionary of voltage_sources."""
 
-        return self.analysis['voltage_sources']
+        return self.analysis.voltage_sources
 
     @property
     def current_sources(self):
         """Return dictionary of current_sources."""
 
-        return self.analysis['current_sources']
+        return self.analysis.current_sources
 
     @property
     def ics(self):
         """Return dictionary of components with initial conditions."""
 
-        return self.analysis['ics']
+        return self.analysis.ics
 
     @property
     def independent_sources(self):
         """Return dictionary of independent sources (this does not include
         implicit sources due to initial conditions)."""
 
-        return self.analysis['independent_sources']
+        return self.analysis.independent_sources
 
     @property
     def dependent_sources(self):
         """Return dictionary of dependent sources."""
 
-        return self.analysis['dependent_sources']
+        return self.analysis.dependent_sources
 
     def independent_source_groups(self, transform=False):
         """Return dictionary of source groups.  Each group is a list of
@@ -2341,7 +2418,7 @@ class NetlistMixin(object):
     def control_sources(self):
         """Return list of voltage sources required to specify control
         current for CCVS and CCCS components."""
-        return self.analysis['control_sources']
+        return self.analysis.control_sources
 
     @property
     def analysis(self):
@@ -2353,92 +2430,7 @@ class NetlistMixin(object):
 
     def analyse(self):
 
-        has_ic = False
-        zeroic = True
-        has_s = False
-        has_transient = False
-        ac_count = 0
-        dc_count = 0
-        causal = True
-        reactive = False
-        independent_sources = []
-        dependent_sources = []
-        control_sources = []
-        reactances = []
-        transformers = []
-        capacitors = []
-        inductors = []
-        voltage_sources = []
-        current_sources = []
-        ics = []
-
-        for eltname, elt in self.elements.items():
-            if elt.need_control_current:
-                control_sources.append(elt.args[0])
-            if elt.has_ic is not None:
-                if elt.has_ic:
-                    has_ic = True
-                    ics.append(eltname)
-                if not elt.zeroic:
-                    zeroic = False
-            if elt.independent_source:
-                independent_sources.append(eltname)
-                if elt.has_s_transient:
-                    has_s = True
-                if elt.has_transient:
-                    has_transient = True
-                if elt.is_ac:
-                    ac_count += 1
-                if elt.is_dc:
-                    dc_count += 1
-                if not elt.is_causal:
-                    causal = False
-            if elt.dependent_source:
-                dependent_sources.append(eltname)
-            if elt.reactive:
-                reactive = True
-                reactances.append(eltname)
-            if elt.is_transformer:
-                transformers.append(eltname)
-            elif elt.is_capacitor:
-                capacitors.append(eltname)
-            elif elt.is_inductor:
-                inductors.append(eltname)
-            elif elt.is_voltage_source:
-                voltage_sources.append(eltname)
-            elif elt.is_current_source:
-                current_sources.append(eltname)
-
-        num_sources = len(independent_sources)
-
-        analysis = {}
-        analysis['zeroic'] = zeroic
-        analysis['has_ic'] = has_ic
-        analysis['ivp'] = has_ic
-        analysis['has_dc'] = dc_count > 0
-        analysis['has_ac'] = ac_count > 0
-        analysis['has_s'] = has_s
-        analysis['has_transient'] = has_transient
-        analysis['reactances'] = reactances
-        analysis['transformers'] = transformers
-        analysis['capacitors'] = capacitors
-        analysis['inductors'] = inductors
-        analysis['voltage_sources'] = voltage_sources
-        analysis['current_sources'] = current_sources
-        analysis['ics'] = ics
-        analysis['dependent_sources'] = dependent_sources
-        analysis['independent_sources'] = independent_sources
-        analysis['control_sources'] = control_sources
-        analysis['ac'] = ac_count > 0 and (
-            num_sources == ac_count) and not has_ic
-        analysis['dc'] = dc_count > 0 and (
-            num_sources == dc_count) and not has_ic
-        analysis['causal'] = causal and zeroic
-        analysis['time_domain'] = not reactive and not has_s
-
-        if not reactive and has_ic:
-            raise ValueError('Non-reactive component with initial conditions')
-        return analysis
+        return Analysis(self)
 
     def describe(self):
         """Print a message describing how circuit is solved."""
@@ -2453,14 +2445,18 @@ class NetlistMixin(object):
             return '%s analysis is used for %s.' % (method,
                                                     describe_sources(sources))
 
-        groups = self.independent_source_groups(transform=not
-                                                self.is_time_domain)
+        if self.is_switching:
+            print('''This has switches and thus is time variant.  Use the convert_IVP(t) method to convert to an initial value problem, specifying the time when to evaluate the switches.''')
+            return
+
+        groups = self.independent_source_groups(
+            transform=not self.is_time_domain)
 
         if groups == {}:
             print('There are no non-zero independent sources so everything is zero.')
             return
 
-        if self.is_ivp:
+        if self.is_IVP:
             print('This has initial conditions for %s so is an initial value '
                   'problem solved in the s-domain using Laplace transforms.' %
                   ', '.join(self.ics))
