@@ -30,6 +30,7 @@ Copyright 2014--2021 Michael Hayes, UCECE
 """
 
 from __future__ import division
+from .expressionclasses import expressionclasses
 from .acdc import ACChecker
 from .domains import PhasorTimeDomain, PhasorFrequencyDomain
 from .sym import j, omegasym
@@ -37,11 +38,6 @@ from .expr import expr
 from .functions import sin, cos, exp, sqrt
 from .expr import Expr
 from .omegaexpr import omega
-from .voltagemixin import VoltageMixin
-from .currentmixin import CurrentMixin
-from .admittancemixin import AdmittanceMixin
-from .impedancemixin import ImpedanceMixin
-from .transfermixin import TransferMixin
 from sympy import Expr as symExpr
 from warnings import warn
 
@@ -61,7 +57,6 @@ __all__ = ('phasor', )
 # C) + delta(omega) / (2 C).
 
 
-
 class PhasorExpression(Expr):
 
     @property
@@ -85,19 +80,6 @@ class PhasorExpression(Expr):
 
         return var
 
-    def fourier(self, **assumptions):
-        """Fourier transform."""
-
-        return self.time().fourier()
-
-    def angular_fourier(self, **assumptions):
-        """Angular Fourier transform."""
-
-        if self.has(omega):
-            warn('Expression contains omega, should substitute with a different symbol.')
-
-        return self.time().angular_fourier()
-
     def phasor(self, **assumptions):
         """Convert to phasor representation."""
 
@@ -118,7 +100,6 @@ class PhasorExpression(Expr):
         the angular frequency limits."""
 
         from .plot import plot_phasor, plot_angular_frequency
-        from .sym import pi, fsym
 
         if self.is_phasor_time_domain:
             return plot_phasor(self, **kwargs)
@@ -128,20 +109,22 @@ class PhasorExpression(Expr):
 
         return plot_angular_frequency(self, wvector, **kwargs)
 
-    def bode_plot(self, fvector=None, **kwargs):
+    def bode_plot(self, fvector=None, unwrap=True, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Bode
         plot (but without the straight line approximations).  fvector
         specifies the frequencies.  If it is a tuple (m1, m2), it sets the
-        frequency limits as (10**m1, 10**m2)."""
+        frequency limits as (10**m1, 10**m2).
+
+        `unwrap` controls phase unwrapping (default True).
+        """
 
         from .plot import plot_bode
-        from .sym import pi, fsym
 
         if not self.is_phasor_frequency_domain:
             raise ValueError('Not frequency domain phasor: use plot()')
 
         result = self.fourier()
-        return plot_bode(result, fvector, **kwargs)
+        return plot_bode(result, fvector, unwrap=unwrap, **kwargs)
 
     def _mul_compatible(self, x):
 
@@ -194,7 +177,7 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
             assumptions['omega'] = assumptions['omega'].expr
 
         assumptions['ac'] = True
-        super (PhasorExpression, self).__init__(val, **assumptions)
+        super(PhasorExpression, self).__init__(val, **assumptions)
 
     def _class_by_quantity(self, quantity, domain=None):
 
@@ -212,7 +195,8 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
         from .symbols import t
 
         if expr.is_admittance or expr.is_impedance or expr.is_transfer:
-            warn('Should convert %s expression to Laplace-domain first.' % expr.quantity)
+            warn('Should convert %s expression to Laplace-domain first.' %
+                 expr.quantity)
 
         assumptions['ac'] = True
 
@@ -226,7 +210,8 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
                 'Do not know how to convert %s to phasor.  Expecting an AC signal.' % expr)
 
         if omega is not None and check.omega != omega:
-            raise ValueError('Expecting omega=%s, found omega=%s.' % (omega, check.omega))
+            raise ValueError('Expecting omega=%s, found omega=%s.' %
+                             (omega, check.omega))
 
         if check.omega == 0:
             warn('DC phasor.')
@@ -249,7 +234,8 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
         if self.is_complex_signal:
             result = self.expr * exp(j * omega1 * t)
         else:
-            result = self.real.expr * cos(omega1 * t) - self.imag.expr * sin(omega1 * t)
+            result = self.real.expr * \
+                cos(omega1 * t) - self.imag.expr * sin(omega1 * t)
 
         return TimeDomainExpression(result).as_quantity(self.quantity)
 
@@ -258,6 +244,19 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
 
         return self.time().laplace()
 
+    def angular_fourier(self, **assumptions):
+        """Angular Fourier transform."""
+
+        if self.has(omega):
+            warn('Expression contains omega, should substitute with a different symbol.')
+
+        return self.time().angular_fourier()
+
+    def fourier(self, **assumptions):
+        """Fourier transform."""
+
+        return self.time().fourier()
+
 
 class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
     """This represents the ratio of two-phasors; for example
@@ -279,7 +278,7 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
         else:
             ass = assumptions
 
-        super (PhasorExpression, self).__init__(val, **ass)
+        super(PhasorExpression, self).__init__(val, **ass)
 
     def _class_by_quantity(self, quantity, domain=None):
 
@@ -303,7 +302,8 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
             omega = omega.expr
 
         if expr.is_voltage or expr.is_current:
-            warn('Should convert %s expression to time-domain first.' % expr.quantity)
+            warn('Should convert %s expression to time-domain first.' %
+                 expr.quantity)
 
         # Substitute jw for s
         result = expr.laplace(**ass)
@@ -336,6 +336,20 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
         result = self.expr.replace(omega, ssym / j)
         return LaplaceDomainExpression(result, **assumptions).as_quantity(self.quantity)
 
+    def angular_fourier(self, **assumptions):
+        """Angular Fourier transform."""
+
+        if self.var is omega:
+            # TODO, add warning.
+            pass
+
+        return self.time().angular_fourier()
+
+    def fourier(self, **assumptions):
+        """Fourier transform."""
+
+        return self.time().fourier()
+
     def as_expr(self):
         return PhasorFrequencyDomainExpression(self)
 
@@ -368,12 +382,10 @@ def phasor(arg, omega=None, **assumptions):
         return PhasorFrequencyDomainExpression(arg, omega=omega, **assumptions)
 
 
-from .expressionclasses import expressionclasses
-
 expressionclasses.register('phasor', PhasorTimeDomainExpression,
                            PhasorFrequencyDomainExpression,
                            ('voltage', 'current',
                             'voltagesquared', 'currentsquared', 'undefined'))
 
-from .texpr import TimeDomainExpression
-from .expr import Expr
+from .texpr import TimeDomainExpression  # nopep8
+from .expr import Expr  # nopep8
