@@ -434,6 +434,7 @@ class Schematic(NetfileMixin):
         self.cpt_size = float(kwargs.pop('cpt_size', 1.2))
         self.node_spacing = float(kwargs.pop('node_spacing', 2.0))
         self.scale = float(kwargs.pop('scale', 1.0))
+        png_converter = kwargs.pop('png_converter', None)
 
         include = ''
         if 'include' in kwargs:
@@ -456,7 +457,7 @@ class Schematic(NetfileMixin):
         # For debugging when do not want to write to file
         nosave = kwargs.pop('nosave', False)
 
-        latexrunner = LatexRunner(self.debug & 2)
+        latexrunner = LatexRunner((self.debug & 2) != 0)
 
         content = self._tikz_draw(style_args=style_args, **kwargs)
 
@@ -510,15 +511,16 @@ class Schematic(NetfileMixin):
             return
 
         if ext == '.svg':
-            pdfconverter = PDFConverter(self.debug & 2)
+            pdfconverter = PDFConverter((self.debug & 2) != 0)
             pdfconverter.to_svg(pdf_filename, root + '.svg')
             if not (self.debug & 1):
                 remove(pdf_filename)
             return
 
         if ext == '.png':
-            pdfconverter = PDFConverter(self.debug & 2)
-            pdfconverter.to_png(pdf_filename, root + '.png', self.dpi)
+            pdfconverter = PDFConverter((self.debug & 2) != 0)
+            pdfconverter.to_png(pdf_filename, root + '.png', dpi=self.dpi,
+                                method=png_converter)
             if not (self.debug & 1):
                 remove(pdf_filename)
             return
