@@ -11,7 +11,8 @@ from .inverse_laplace import inverse_laplace_transform
 from .state import state
 from .sym import ssym, tsym, j, pi, sympify
 from .ratfun import _zp2tf, _pr2tf, Ratfun
-from .expr import Expr, symbol, expr, ExprDict, exprcontainer, expr_make
+from .expr import Expr, symbol, expr, ExprDict, ExprList, exprcontainer, expr_make
+from .differentialequation import DifferentialEquation
 from .units import u as uu
 from .functions import sqrt, DiracDelta
 from .sym import dt
@@ -429,7 +430,7 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
 
         return self.state_space()
 
-    def differential_equation(self, input='x', output='y'):
+    def differential_equation(self, inputsym='x', outputsym='y'):
         """Create differential equation from transfer function.
 
         For example,
@@ -441,20 +442,44 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
                                      dt
         """
 
-        H = self
-        x = texpr('%s(t)' % input)
-        y = texpr('%s(t)' % output)
+        x = texpr('%s(t)' % inputsym)
+        y = texpr('%s(t)' % outputsym)
 
         X = x.LT()
         Y = y.LT()
 
+        H = self.simplify()
+        N = H.N
+        D = H.D
+
+        lhs = (N * Y).ILT(causal=True, zero_initial_conditions=True)
+        rhs = (D * X).ILT(causal=True, zero_initial_conditions=True)
+
+        return DifferentialEquation(lhs, rhs, inputsym, outputsym)
+
+    def lti_filter(self, normalize_a0=True):
+        """Create continuous-time linear time-invariant filter from
+        continuous-time transfer function."""
+
+        # TODO, perhaps add only to TimeDomainTransfer
+        # or check that is_transfer, is_impedance, or is_admittance
+
+        from .ltifilter import LTIFilter
+
+        if not self.is_rational_function:
+            raise ValueError("Not a rational function")
+
         N = self.N
         D = self.D
+        bn = N.coeffs()
+        an = D.coeffs()
 
-        lhs = (N * Y).ILT(causal=True)
-        rhs = (D * X).ILT(causal=True)
+        if normalize_a0:
+            bn = [bx / an[0] for bx in bn]
+            an = [ax / an[0] for ax in an]
 
-        return TimeDomainExpression(Eq(lhs.expr, rhs.expr))
+        lpf = LTIFilter(bn, an)
+        return lpf
 
     def dlti_filter(self, method='bilinear'):
         """Create DLTI filter using bilinear transform."""
